Crate codex_windows_sandbox

Crate codex_windows_sandbox 

Structs

CaptureResult
WindowsSandboxCancellationToken
Cancellation hook used by Windows sandbox capture backends.
WindowsSandboxProvisioningSettings
Network settings installed by an administrator during managed Windows sandbox setup.

Enums

WindowsSandboxProxySettingsMode
Controls whether a Windows sandbox launch reconciles persistent proxy firewall settings or preserves the settings established by another launch.

Functions

resolve_windows_deny_read_paths
Resolve split filesystem None read entries into concrete Windows ACL targets.
run_windows_sandbox_capture
run_windows_sandbox_legacy_preflight