pub enum WindowsSandboxProxySettingsMode {
Reconcile,
Preserve,
}Expand description
Controls whether a Windows sandbox launch reconciles persistent proxy firewall settings or preserves the settings established by another launch.
Variants